@@ -1,6 +1,6 @@
+import ssl
 from typing import Any, Dict, Optional
 from nornir.core.configuration import Config
-from nornir.core.plugins.connections import ConnectionPlugin
 from routeros_api import RouterOsApiPool
 
 CONNECTION_NAME = "routerosapi"
@@ -34,8 +34,17 @@ class RouterOsApi:
             "password": password,
             "port": port,
             "plaintext_login": True,
-            "use_ssl": True,
+            "use_ssl": True
         }
+
+        if extras is not None and extras.get("use_ssl", True):
+            ssl_ctx = ssl.create_default_context()
+            ssl_ctx.verify_mode = ssl.CERT_REQUIRED if extras.get("ssl_verify", True) else ssl.CERT_NONE
+            ssl_ctx.check_hostname = extras.get("ssl_verify_hostname", False)
+            if "ssl_ca_file" in extras:
+                ssl_ctx.load_verify_locations(extras.pop("ssl_ca_file"))
+            params["ssl_context"] = ssl_ctx
+
         extras = extras or {}
         params.update(extras)
         self._pool = RouterOsApiPool(**params)
